@@ -1,7 +1,7 @@
 package Pod::Weaver::Role::AddTextToSection;
 
-our $DATE = '2015-04-04'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2017-01-14'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use Moose::Role;
@@ -89,7 +89,7 @@ sub add_text_to_section {
             }
         } else {
             $self->log_debug(["Skipping adding text because section $section already exists"]);
-            return if $opts->{ignore};
+            return 0 if $opts->{ignore};
         }
     }
 
@@ -103,6 +103,7 @@ sub add_text_to_section {
             push @{ $section_elem->children }, @{ $text_elem->children };
         }
     }
+    return 1;
 }
 
 no Moose::Role;
@@ -121,7 +122,7 @@ Pod::Weaver::Role::AddTextToSection - Add text to a section
 
 =head1 VERSION
 
-This document describes version 0.05 of Pod::Weaver::Role::AddTextToSection (from Perl distribution Pod-Weaver-Role-AddTextToSection), released on 2015-04-04.
+This document describes version 0.06 of Pod::Weaver::Role::AddTextToSection (from Perl distribution Pod-Weaver-Role-AddTextToSection), released on 2017-01-14.
 
 =head1 SYNOPSIS
 
@@ -150,7 +151,7 @@ This document describes version 0.05 of Pod::Weaver::Role::AddTextToSection (fro
 
 =head1 METHODS
 
-=head2 $obj->add_text_to_section($document, $text, $section[, \%opts])
+=head2 $obj->add_text_to_section($document, $text, $section[, \%opts]) => bool
 
 Add a string C<$text> to a section named C<$section>.
 
@@ -170,6 +171,9 @@ true, not unlike C<INSERT OR IGNORE> in SQL) or will add text. Text will be
 added at the bottom the existing text, unless when C<top> option is true in
 which case will text will be added at the top the existing text.
 
+Will return a boolean status which is true when text is actually added to the
+section.
+
 Options:
 
 =over
@@ -203,15 +207,25 @@ bottom.
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver-Role-AddTextToSection>.
 
+=head1 SOURCE
+
 Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Role-AddTextToSection>.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Weaver-Role-AddTextToSection>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
